//@HEADER
// ************************************************************************
//
//                        Kokkos v. 4.0
//       Copyright (2022) National Technology & Engineering
//               Solutions of Sandia, LLC (NTESS).
//
// Under the terms of Contract DE-NA0003525 with NTESS,
// the U.S. Government retains certain rights in this software.
//
// Part of Kokkos, under the Apache License v2.0 with LLVM Exceptions.
// See https://kokkos.org/LICENSE for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
//@HEADER

#include "PerfTest_ViewResize.hpp"

namespace Test {

// FIXME_SYCL Avoid running out of resources on the CUDA GPU used in the CI
#ifdef KOKKOS_ENABLE_SYCL
static constexpr int N_8 = N - 1;
#else
static constexpr int N_8 = N;
#endif

BENCHMARK(ViewResize_Rank8<Kokkos::LayoutLeft>)
    ->ArgName("N")
    ->Arg(N_8)
    ->UseManualTime()
    ->Iterations(R);

BENCHMARK(ViewResize_Rank8<Kokkos::LayoutRight>)
    ->ArgName("N")
    ->Arg(N_8)
    ->UseManualTime()
    ->Iterations(R);

BENCHMARK(ViewResize_NoInit_Rank8<Kokkos::LayoutLeft>)
    ->ArgName("N")
    ->Arg(N_8)
    ->UseManualTime()
    ->Iterations(R);

BENCHMARK(ViewResize_NoInit_Rank8<Kokkos::LayoutRight>)
    ->ArgName("N")
    ->Arg(N_8)
    ->UseManualTime()
    ->Iterations(R);

}  // namespace Test
